==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/InputPreferences/ts/InputPreferences_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Input</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Decimal Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przecinku:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Cartesian Coordinate Separator:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Separator współrzędnych kartezjański:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Polar Coordinate Separator:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Polar Separator współrzędnych:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Relative Coordinate Prefix:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Względna Prefiks współrzędnych:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Examples</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przykłady</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Absolute Cartesian Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Absolute kartezjańskich współrzędnych:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Absolute Polar Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Absolute Polar współrzędnych:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Relative Cartesian Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Względna współrzędnych kartezjańskich:</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Relative Polar Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Względna Polar współrzędnych:</translation>
    </message>
</context>
<context>
    <name>InputPreferences</name>
    <message>
        <location filename="../InputPreferences.js" line="+32"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="unfinished">Ogólny</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Coordinate Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Format współrzędnych</translation>
    </message>
    <message>
        <location line="+15"/>
        <location line="+27"/>
        <source>Comma</source>
        <translatorcomment>--google--
Aktywuj linię poleceń
Aktywuj linię &amp;poleceń
Linia poleceń</translatorcomment>
        <translation type="unfinished">Przecinek</translation>
    </message>
    <message>
        <location line="-27"/>
        <location line="+6"/>
        <location line="+5"/>
        <location line="+15"/>
        <source>(Default)</source>
        <translatorcomment>--google--
Automatyczny (domyślnie)
Ustawienia pulpitu (domyślne)</translatorcomment>
        <translation type="unfinished">(Default)</translation>
    </message>
    <message>
        <location line="-25"/>
        <source>Semicolon</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Średnik</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Less Than</source>
        <translatorcomment>--google--
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2 typu podstawowego.
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2 typu podstawowego
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2.
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2
Wartość aspektu %1 musi być mniejsza od wartości aspektu %2 typu podstawowego.</translatorcomment>
        <translation type="unfinished">Mniej niż</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>At</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
O aplikacji
Tworzenie nowego pliku...</translatorcomment>
        <translation type="unfinished">przy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Percentage</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Odsetek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dollar</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dolar ($)
Dolar</translatorcomment>
        <translation type="unfinished">Dolar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hash</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Hash (#)
Hash</translatorcomment>
        <translation type="unfinished">Hash</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
K&amp;ropkowanie siatki:
K&amp;ropkowanie siatki
Kropkowanie siatki:</translatorcomment>
        <translation type="unfinished">Kropka</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/InputPreferences/ts/InputPreferences_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Input</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Decimal Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Separator dziesiętny:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Cartesian Coordinate Separator:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Separator współrzędnych kartezjańskich:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Polar Coordinate Separator:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Separator współrzędnych biegunowych:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Relative Coordinate Prefix:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Prefiks współrzędnych względnych:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Examples</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przykłady</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Absolute Cartesian Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bezwzględna współrzędna kartezjańska:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Absolute Polar Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bezwzględna współrzędna biegunowa:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Relative Cartesian Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Względna współrzędna kartezjańska:</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Relative Polar Coordinate:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Względna współrzędna biegunowa:</translation>
    </message>
</context>
<context>
    <name>InputPreferences</name>
    <message>
        <location filename="../InputPreferences.js" line="+32"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Coordinate Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Format współrzędnych</translation>
    </message>
    <message>
        <location line="+15"/>
        <location line="+27"/>
        <source>Comma</source>
        <translatorcomment>--google--
Aktywuj linię poleceń
Aktywuj linię &amp;poleceń
Linia poleceń</translatorcomment>
        <translation>Przecinek</translation>
    </message>
    <message>
        <location line="-27"/>
        <location line="+6"/>
        <location line="+5"/>
        <location line="+15"/>
        <source>(Default)</source>
        <translatorcomment>--google--
Automatyczny (domyślnie)
Ustawienia pulpitu (domyślne)</translatorcomment>
        <translation>(Domyślnie)</translation>
    </message>
    <message>
        <location line="-25"/>
        <source>Semicolon</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Średnik</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Less Than</source>
        <translatorcomment>--google--
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2 typu podstawowego.
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2 typu podstawowego
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2.
Wartość aspektu %1 musi być mniejsza od lub równa wartości aspektu %2
Wartość aspektu %1 musi być mniejsza od wartości aspektu %2 typu podstawowego.</translatorcomment>
        <translation>Mniej niż</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>At</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
O aplikacji
Tworzenie nowego pliku...</translatorcomment>
        <translation>Przy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Percentage</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Procent</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dollar</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dolar ($)
Dolar</translatorcomment>
        <translation>Dolar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hash</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Hash (#)
Hash</translatorcomment>
        <translation>Kratka</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
K&amp;ropkowanie siatki:
K&amp;ropkowanie siatki
Kropkowanie siatki:</translatorcomment>
        <translation>Kropka</translation>
    </message>
</context>
</TS>
